Ghost = Object:extend()

function Ghost:new(x, y)
    self.x = 0
    self.y = 0
    self.originX = x
    self.originY = y
    self.targetX = love.math.random(self.originX-200, self.originX+200)
    self.targetY = love.math.random(self.originY-200, self.originY+200)
    self.sprite = love.graphics.newImage('halloween/ghost2.png')
    self.grid = anim8.newGrid(156/3, 288/4, self.sprite:getWidth(), self.sprite:getHeight())
    self.animations = {}
    self.animations.walkdown = anim8.newAnimation(self.grid(1, 1, 2, 1, 3, 1, 2, 1), 0.1)
    self.animations.walkleft = anim8.newAnimation(self.grid(1, 2, 2, 2, 3, 2, 2, 2), 0.1)
    self.animations.walkright = anim8.newAnimation(self.grid(1, 3, 2, 3, 3, 3, 2, 3), 0.1)
    self.animations.walkup = anim8.newAnimation(self.grid(1, 4, 2, 4, 3, 4, 2, 4), 0.1)
    self.anim = self.animations.walkleft
    
    self.collider = world:newRectangleCollider(self.originX, self.originY, 32, 32)
    self.collider:setCollisionClass('Ghost')
    self.collider:setObject(self)
    
    self.state = ""
    self.distance = 101
    self.speedX = 0
    self.speedY = 0
    self.hp = 5
    self.hpbaropacity = 0
end

function Ghost:takeDamage()
    self.hp = self.hp - 1
end

function Ghost:update(dt)
    self.anim:update(dt)
    if self.collider ~= nil then
        self.x = self.collider:getX()
        self.y = self.collider:getY()
        
        self.distance = math.sqrt( (self.x-player.collider:getX())*(self.x-player.collider:getX()) + (self.y-player.collider:getY())*(self.y-player.collider:getY()))
        
        if self.distance < 100 then
            self.state = "chasing"
        else
            self.state = "fly"
        end
        
        if self.state == "fly" then
            
            if self.x < self.targetX then
                self.collider:setX(self.collider:getX()+1)
            end
            
            if self.x > self.targetX then
                self.collider:setX(self.collider:getX()-1)
            end
            
            if self.y < self.targetY then
                self.collider:setY(self.collider:getY()+1)
            end
            
            if self.y > self.targetY then
                self.collider:setY(self.collider:getY()-1)
            end
            
            if self.x == self.targetX and self.y == self.targetY then
                self.targetX = love.math.random(self.originX-200, self.originX+200)
                self.targetY = love.math.random(self.originY-200, self.originY+200)
            end
        end
        
        if self.state == "chasing" then
            
        end
        
        if self.collider:enter('Bullet') then
            local collision_data = self.collider:getEnterCollisionData('Bullet')
            local bulletnow = collision_data.collider:getObject()
            if bulletnow ~= nil then
                bulletnow:boom()
            end
            self.hpbaropacity = 100
            self:takeDamage()
        end
        
        if self.hp <= 0 then
            self:boom()
        end
    
        if self.hpbaropacity>0 then
            self.hpbaropacity = self.hpbaropacity - 1
        end
        
        
    end
    
end

function Ghost:boom()
    for k2, v2 in ipairs(listOfGhosts) do
	      if v2 == self then
            self.collider:destroy()
            table.remove(listOfGhosts, k2) 
            break 
        end
    end
end

function Ghost:draw()
    local px = self.collider:getX()
    local py = self.collider:getY()
    love.graphics.setColor(255, 255, 255, self.hpbaropacity)
    love.graphics.rectangle("fill", px-25, py-50, 50, 5)
    love.graphics.setColor(0, 255, 0, self.hpbaropacity)
    love.graphics.rectangle("fill", px-25, py-50, self.hp*10, 5)
    love.graphics.setColor(255, 255, 255)
    self.anim:draw(self.sprite, px, py, nil, nil, nil, 156/3/2, 56)
end