Player = Object:extend()

function Player:new()
    self.width = 32
    self.height = 64
    self.x = 400
    self.y = 300
    self.sprite = love.graphics.newImage('halloween/horseman/jacko_a_2.png')
    self.grid = anim8.newGrid(156/3, 288/4, self.sprite:getWidth(), self.sprite:getHeight())
    self.animations = {}
    self.animations.walkdown = anim8.newAnimation(self.grid(1, 1, 2, 1, 3, 1, 2, 1), 0.1)
    self.animations.walkleft = anim8.newAnimation(self.grid(1, 2, 2, 2, 3, 2, 2, 2), 0.1)
    self.animations.walkright = anim8.newAnimation(self.grid(1, 3, 2, 3, 3, 3, 2, 3), 0.1)
    self.animations.walkup = anim8.newAnimation(self.grid(1, 4, 2, 4, 3, 4, 2, 4), 0.1)
    self.anim = self.animations.walkleft
    
    self.collider = world:newRectangleCollider(self.x, self.y, 32, 32)
    self.collider:setCollisionClass('Player')
    self.collider:setObject(self)
    
    
    self.isMoving = false
    self.dir = "down"
    self.bulletReload = 30
end

function Player:update(dt)
  
    self.x =self.collider:getX()
    self.y = self.collider:getY()
    if self.isMoving then
        self.anim:update(dt)
    end
    
    local vectorX = 0
    local vectorY = 0
    
    if love.keyboard.isDown("down") then
        vectorY = 1
        self.anim = self.animations.walkdown
        self.dir = "down"
    end 
    
    if love.keyboard.isDown("left") then
        vectorX = -1
        self.anim = self.animations.walkleft
        self.dir = "left"
    end 
    
    if love.keyboard.isDown("right") then
        vectorX = 1
        self.anim = self.animations.walkright
        self.dir = "right"
    end 
    
    if love.keyboard.isDown("up") then
        vectorY = -1
        self.anim = self.animations.walkup
        self.dir = "up"
    end 
    self.collider:setLinearVelocity(vectorX * 100, vectorY * 100)
    
    if vectorX == 0 and vectorY == 0 then
        self.isMoving = false
        self.anim:gotoFrame(2) 
    else
        self.isMoving = true
    end
    
    if self.bulletReload >= 0 then
        self.bulletReload = self.bulletReload - 1
    end
    
    if love.keyboard.isDown("space") and self.bulletReload < 0 then
        if self.dir == "down" then
            table.insert(listOfBullets, Bullet(self.collider:getX()-16, self.collider:getY()-16, 32, 32, 200, 50, "todown", "pumpkin"))
        elseif self.dir == "left" then
            table.insert(listOfBullets, Bullet(self.collider:getX()-16, self.collider:getY()-16, 32, 32, 200, 50, "toleft", "pumpkin"))
        elseif self.dir == "right" then
            table.insert(listOfBullets, Bullet(self.collider:getX()-16, self.collider:getY()-16, 32, 32, 200, 50, "toright", "pumpkin"))
        else
            table.insert(listOfBullets, Bullet(self.collider:getX()-16, self.collider:getY()-16, 32, 32, 200, 50, "toup", "pumpkin"))
        end
        self.bulletReload = 20
    end
end

function Player:draw()
    local px = self.collider:getX()
    local py = self.collider:getY()
    self.anim:draw(self.sprite, px, py, nil, nil, nil, 156/3/2, 56)
end